package com.tomtom.business.ubi.sample;

import com.tomtom.business.ubi.sample.SampleService.SampleServiceBinder;

import android.app.Activity;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.util.Log;

/**
 * A simple sample Android Activity demonstrating the TomTom UBI SDK for Android 
 * using a custom back-end service {@link SampleService} which hosts the connection the Core.
 *  
 * Please see the documentation in the library project for more information.
 *
 * Copyright (c) 2016 TomTom Telematics, all rights reserved.
 */
public class SampleServiceActivity extends Activity 
{
    private static final String LOG_TAG = SampleServiceActivity.class.getName();
    
    /**
     * Keep a ref for unbinding...
     */
    private ServiceConnection serviceConnection;
    
    /**
     * 
     */
    private SampleService service;
    
    /**
     * Simple implementation of an Android service connection.
     */
    private final class MyServiceConnection implements ServiceConnection
    {
        @Override
        public void onServiceDisconnected(ComponentName name)
        {
        }

        @Override
        public void onServiceConnected(ComponentName name, IBinder service)
        {
            Log.i(LOG_TAG, "Bound to sample service, starting actual UBI service");
            SampleServiceActivity.this.service = ((SampleServiceBinder) service).getService();
            SampleServiceActivity.this.service.startCoreService();
        }
    }    
        
    
    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        this.setContentView(R.layout.sample_service_activity);
        
        Log.i(LOG_TAG, "Binding to sample service...");
        this.serviceConnection = new MyServiceConnection();
        
        Intent bindIntent = new Intent(this, SampleService.class);
        this.bindService(bindIntent, this.serviceConnection, Context.BIND_AUTO_CREATE);        
    }
    
    @Override
    protected void onDestroy()
    {
        this.unbindService(this.serviceConnection);
        super.onDestroy();
    }
}
